@@ -128,7 +128,7 @@ void ImportTab::makeGUI()
 	QVBoxLayout *mainLayout = new QVBoxLayout;
 	mainLayout->addWidget(informationText);
 	QVBoxLayout *buttonLayout = new QVBoxLayout;
-	buttonLayout->setMargin(0);
+	buttonLayout->setContentsMargins(0, 0, 0, 0);
 	buttonLayout->setSpacing(2);
 	buttonLayout->addStretch(1);
 	buttonLayout->addWidget(addButton);
