@@ -498,21 +498,13 @@ This can be set in the preferences menu.</source>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="110"/>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="330"/>
         <source>Start daemon</source>
-        <translation type="unfinished"></translation>
+        <translation>شغّل الجنيّ</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="117"/>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="331"/>
         <source>Stop daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Start deamon</source>
-        <translation type="obsolete">شغّل الجنيّ</translation>
-    </message>
-    <message>
-        <source>Stop deamon</source>
-        <translation type="obsolete">أوقف الجنيّ</translation>
+        <translation>أوقف الجنيّ</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="59"/>
@@ -790,10 +782,6 @@ This can be set in the preferences menu.</source>
         <source>&lt;h4&gt;New&lt;/h4&gt; &lt;p&gt;Creates a &lt;em&gt;new&lt;/em&gt; project.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;جديد&lt;/h4&gt; &lt;p&gt;ينشئ مشروعا  &lt;em&gt;جديدا&lt;/em&gt; .&lt;/p&gt;</translation>
     </message>
-    <message>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="obsolete">&lt;h4&gt;احفظ&lt;/h4&gt; &lt;p&gt;&lt;em&gt;يحفظ&lt;/em&gt; التحريك الحالي كملف مشروع تحريك. &lt;BR&gt;إن كان المشروع قد حُفظ مسبقا فسيتم تحديثه في ذات الملف الذي حفظ فيه مسبقا.&lt;/p&gt;</translation>
-    </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="608"/>
         <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
@@ -838,7 +826,7 @@ This can be set in the preferences menu.</source>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="598"/>
         <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;h4&gt;احفظ&lt;/h4&gt; &lt;p&gt;&lt;em&gt;يحفظ&lt;/em&gt; التحريك الحالي كملف مشروع تحريك. &lt;BR&gt;إن كان المشروع قد حُفظ مسبقا فسيتم تحديثه في ذات الملف الذي حفظ فيه مسبقا.&lt;/p&gt;</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="604"/>
@@ -1076,10 +1064,6 @@ to check your settings in the preferences menu?</source>
         <source>vgrabbj VGA singleshot</source>
         <translation type="obsolete">تشغيل vgrabbj للقطة VGA ,واحدة</translation>
     </message>
-    <message>
-        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
-        <translation type="obsolete">يشغّل vgrabbj كجنيّ. سريع للغاية.</translation>
-    </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="418"/>
         <source>Question</source>
@@ -1133,7 +1117,7 @@ to check your settings in the preferences menu?</source>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="280"/>
         <source>Starts vgrabbj as a daemon. Pretty fast.</source>
-        <translation type="unfinished"></translation>
+        <translation>يشغّل vgrabbj كجنيّ. سريع للغاية.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="288"/>
@@ -1361,8 +1345,8 @@ to running the image grabbing as a daemon.</source>
     </message>
     <message>
         <source>Playback only currently works when running the grabber 
-as a deamon. Go to the preferences menu (CTRL+P) to switch 
-to running the image grabbing as a deamon.</source>
+as a daemon. Go to the preferences menu (CTRL+P) to switch
+to running the image grabbing as a daemon.</source>
         <translation type="obsolete">حاليا يعمل العرض و حسب أثناء تشغيل اللاقط في طور الجنيّ. يمكنك تشغيل لاقط الصور في طور الجنيّ من قائمة التفضيلات (CTRL+P)</translation>
     </message>
     <message>
