@@ -4,10 +4,8 @@
 <context>
     <name>@default</name>
     <message>
-        <source>You do not have the necessary permissions to run Stopmotion.
-</source>
-        <translation type="obsolete">您沒有運行 Stopmotion 所必要的權限。
-</translation>
+        <source>You do not have the necessary permissions to run Stopmotion.</source>
+        <translation type="obsolete">您沒有運行 Stopmotion 所必要的權限。</translation>
     </message>
 </context>
 <context>
@@ -484,12 +482,12 @@ This can be set in the preferences menu.</source>
         <translation>輪詢前命令</translation>
     </message>
     <message>
-        <source>Start deamon</source>
-        <translation type="obsolete">開始守護程式</translation>
+        <source>Start daemon</source>
+        <translation>開始守護程式</translation>
     </message>
     <message>
-        <source>Stop deamon</source>
-        <translation type="obsolete">停止守護程式</translation>
+        <source>Stop daemon</source>
+        <translation>停止守護程式</translation>
     </message>
     <message>
         <source>Below you can set which program/process Stopmotion should use for grabbing images from the selected device.</source>
@@ -499,14 +497,6 @@ This can be set in the preferences menu.</source>
         <source>You should always use &lt;b&gt;$VIDEODEVICE&lt;/b&gt; and &lt;b&gt;$IMAGEFILE&lt;/b&gt; to represent the video device and the image file, respectively.</source>
         <translation>您應該固定使用&lt;b&gt;$VIDEODEVICE&lt;/b&gt; 和 &lt;b&gt;$IMAGEFILE&lt;/b&gt;以分別表述視訊裝置和圖像檔案。</translation>
     </message>
-    <message>
-        <source>Start daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Stop daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>LanguageHandler</name>
@@ -806,8 +796,8 @@ This can be set in the preferences menu.</source>
         <translation>&lt;h4&gt;新增&lt;/h4&gt;&lt;p&gt;建立&lt;em&gt;新的&lt;/em&gt;專案。&lt;/p&gt;</translation>
     </message>
     <message>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="obsolete">&lt;h4&gt;儲存&lt;/h4&gt;&lt;p&gt;&lt;em&gt;儲存&lt;/em&gt;目前動畫為 Stopmotion 專案檔。&lt;BR&gt;如果此專案之前已儲存，它將自動儲存到之前所選的檔案。&lt;/p&gt;</translation>
+        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
+        <translation>&lt;h4&gt;儲存&lt;/h4&gt;&lt;p&gt;&lt;em&gt;儲存&lt;/em&gt;目前動畫為 Stopmotion 專案檔。&lt;BR&gt;如果此專案之前已儲存，它將自動儲存到之前所選的檔案。&lt;/p&gt;</translation>
     </message>
     <message>
         <source>&lt;h4&gt;Save As&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file.&lt;/p&gt;</source>
@@ -953,10 +943,6 @@ to check your settings in the preferences menu?</source>
         <source>Save As</source>
         <translation>另存新檔</translation>
     </message>
-    <message>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Do&amp;n&apos;t save</source>
         <translation type="unfinished"></translation>
@@ -996,7 +982,7 @@ to check your settings in the preferences menu?</source>
 <context>
     <name>PreferencesMenu</name>
     <message>
-        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the image is saved with the path and filename &lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt; &lt;/p&gt;</source>
+        <source>&lt;p&gt;Below you can set which program/process stopmotion should use for grabbing images from the webcam, and displaying video.&lt;br&gt; &lt;br&gt; You can also add new programs, just make sure the image is saved with the path and filename &lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt; &lt;/p&gt;</source>
         <translation type="obsolete">&lt;p&gt;以下您可以設定 stopmotion 從網路攝影機抓取圖像，以及顯示視訊時應該使用的程式/程序。&lt;br&gt;&lt;br&gt;您也可以加入新的程式，只要確知圖像的儲存路徑和檔名為&lt;b&gt;.stopmotion/capturedfile.png&lt;/b&gt;&lt;/p&gt;</translation>
     </message>
     <message>
@@ -1071,12 +1057,12 @@ to check your settings in the preferences menu?</source>
         <translation type="obsolete">vgrabbj VGA 單次拍照</translation>
     </message>
     <message>
-        <source>vgrabbj VGA deamon</source>
-        <translation type="obsolete">vgrabbj VGA 守護程式</translation>
+        <source>vgrabbj VGA daemon</source>
+        <translation>vgrabbj VGA 守護程式</translation>
     </message>
     <message>
-        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
-        <translation type="obsolete">啟動 vgrabbj 為守護程式。相當快速。</translation>
+        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
+        <translation>啟動 vgrabbj 為守護程式。相當快速。</translation>
     </message>
     <message>
         <source>Question</source>
@@ -1160,19 +1146,11 @@ values exists. Do you want to use this one? (Your old preferences
     </message>
     <message>
         <source>vgrabbj</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>vgrabbj VGA daemon</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
-        <translation type="unfinished"></translation>
+        <translation>vgrabbj</translation>
     </message>
     <message>
         <source>uvccapture</source>
-        <translation type="unfinished"></translation>
+        <translation>uvcapture</translation>
     </message>
     <message>
         <source>Grabbing from V4L2 devices</source>
@@ -1345,8 +1323,8 @@ values exists. Do you want to use this one? (Your old preferences
     </message>
     <message>
         <source>Playback only currently works when running the grabber 
-as a deamon. Go to the preferences menu (CTRL+P) to switch 
-to running the image grabbing as a deamon.</source>
+as a daemon. Go to the preferences menu (CTRL+P) to switch
+to running the image grabbing as a daemon.</source>
         <translation type="obsolete">目前播放控制只在以抓取器做為
 守護程式執行時才有作用。前往偏好設定選單 (Ctrl+P) 
 以切換圖像抓取做為守護程式執行。</translation>
